@@ -1,14 +1,22 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.1.6'
+__version__   = '2.2.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2021-September-11'   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.1.6.html'
-__copyright__ = "(C) 2021 Avinash Kak. Python Software Foundation."
+__date__      = '2022-March-5'
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.2.2.html'
+__copyright__ = "(C) 2022 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
 
+
+  You are looking at the DataPrediction co-class file in the DLStudio module.
+  For the overall documentation on DLStudio, visit:
+
+           https://engineering.purdue.edu/kak/distDLS/
+
+
+
 DATA PREDICTION:
 
     Let's say you have a sequence of observations recorded at regular
