@@ -1,14 +1,22 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.1.6'
+__version__   = '2.2.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2021-September-11'   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.1.6.html'
-__copyright__ = "(C) 2021 Avinash Kak. Python Software Foundation."
+__date__      = '2022-March-5'
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.2.2.html'
+__copyright__ = "(C) 2022 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
 
+
+  You are looking at the Seq2SeqLearning co-class file in the DLStudio module.
+  For the overall documentation on DLStudio, visit:
+
+           https://engineering.purdue.edu/kak/distDLS/
+
+
+
 SEQUENCE-TO-SEQUENCE LEARNING WITH ATTENTION: 
 
     As mentioned in the main doc page for DLStduio, sequence-to-sequence
@@ -19,14 +27,14 @@ SEQUENCE-TO-SEQUENCE LEARNING WITH ATTENTION:
     translation to illustrate the programming idioms and the PyTorch
     structures you need for seq2seq.  
 
-    In version 2.0.9, when I first introduced seq2seq in DLStudio, I placed
+    In version 2.0.9, where I first introduced seq2seq in DLStudio, I placed
     the code inside the main DLStudio class.  However, considering that
-    seq2seq is an active area of research unto itself and that it is highly
-    likely that some of the advances will make their way into DLStudio, it
-    seemed more prudent to give seq2seq its own home.  Therefore, I have
-    moved that code to a co-class of DLStudio --- the class you are looking
-    at as you are reading this doc page.  This class, Seq2SeqLearning,
-    resides at the top-level of the distro.
+    seq2seq is an active area of research and development unto itself, it
+    seems more prudent to give seq2seq its own home.  Therefore, I have moved
+    that code to a co-class of DLStudio --- the class you are looking at as
+    you are reading this doc page.  This class, Seq2SeqLearning, resides at
+    the top-level of the distro.  That makes Seq2SeqLearning a co-class of the
+    main DLStudio class.
 
     In Version 2.1.0, Seq2SeqLearning contains the following two inner
     classes for illustrating seq2seq:
@@ -92,10 +100,6 @@ from DLStudio import DLStudio
 import sys,os,os.path
 import torch
 import torch.nn as nn
-import torch.nn.functional as F
-import torchvision                  
-import torchvision.transforms as tvt
-import torchvision.transforms.functional as tvtF
 import torch.optim as optim
 import numpy as np
 import math
@@ -104,11 +108,8 @@ import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 import time
 import glob                                                                                                           
-import imageio                                                                                                        
 import gzip
 import pickle
-import pymsgbox
-import logging
 
 #___________________________________  Seq2SeqLearning Class Definition  ___________________________________
 
@@ -119,22 +120,18 @@ class Seq2SeqLearning(object):
         if args:
             raise ValueError(  
                    '''Seq2SeqLearning constructor can only be called with keyword arguments for 
-                      the following keywords: epochs, learning_rate, batch_size, momentum, image_size, dataroot, 
-                      path_saved_model, use_gpu, latent_vector_size, ngpu, dlstudio, device, beta1, and debug''')
-        allowed_keys = 'dataroot','image_size','path_saved_model','momentum','learning_rate','epochs','batch_size', \
-                       'classes','use_gpu','latent_vector_size','ngpu','dlstudio', 'beta1','debug'
+                      the following keywords: learning_rate, momentum, dataroot, 
+                      path_saved_model, use_gpu, ngpu, dlstudio, device, beta1, and debug''')
+        allowed_keys = 'dataroot','path_saved_model','momentum','learning_rate', \
+                       'classes','use_gpu','ngpu','dlstudio', 'beta1','debug'
         keywords_used = kwargs.keys()                                                                 
         for keyword in keywords_used:                                                                 
             if keyword not in allowed_keys:                                                           
                 raise SyntaxError(keyword + ":  Wrong keyword used --- check spelling")  
-        learning_rate = epochs = batch_size = convo_layers_config = momentum = None
-        image_size = fc_layers_config = dataroot =  path_saved_model = classes = use_gpu = None
-        latent_vector_size = ngpu = beta1 = debug = None
+        learning_rate = momentum = dataroot =  path_saved_model = classes = use_gpu = ngpu = beta1 = debug = None
         if 'ngpu' in kwargs                          :   ngpu  = kwargs.pop('ngpu')           
         if 'dlstudio' in kwargs                      :   dlstudio  = kwargs.pop('dlstudio')
         if 'debug' in kwargs                         :   debug = kwargs.pop('debug')
-        if latent_vector_size:
-            self.latent_vector_size = latent_vector_size
         if ngpu:
             self.ngpu = ngpu
         if dlstudio:
@@ -315,8 +312,8 @@ class Seq2SeqLearning(object):
             feed into the decoder for generating the target sentence.
 
             In what you see below for the encoder, we do not use an ordinary RNN. On the other
-            hand, we use a GRU (a gated RNN) that I presented in my Week 13 lecture.  As 
-            discussed in the last section of my Week 13 slides, a GRU has some pretty "quirky" 
+            hand, we use a GRU (a gated RNN) that I presented in my Week 12 lecture.  As 
+            discussed in the last section of my Week 12 slides, a GRU has some pretty "quirky" 
             properties that depend on the choices made for the constructor parameters and the 
             shape of the input data.  Let's again say we have an input sequence consisting of 
             10 words (including the two tokens), the GRU is going to see a tensor of shape 
@@ -577,7 +574,7 @@ class Seq2SeqLearning(object):
             such a layer normalizes the values accumulated at those nodes so that they become a legal
             probability distribution over the classes.  Subsequently, calculating the nn.NLLLoss 
             means choosing the negative value in just that node which corresponds to the actual class 
-            lable of the input data. 
+            label of the input data. 
 
             That's exactly how we want to solve the problem of training the decoder here.  The number 
             of nodes in the output layer of the decoder equals the size of the target vocabulary.  For 
@@ -667,7 +664,7 @@ class Seq2SeqLearning(object):
 
         def run_code_for_evaluating_Seq2SeqWithLearnableEmbeddings(self, encoder, decoder):
             """
-            The main difference between the training code and the evaluation code show here
+            The main difference between the training code and the evaluation code shown here
             is with regard to how we process the output of the DecoderRNN.  For the training loop,
             our goal was to use the nn.NLLLoss to choose that value from the output of the decoder
             that corresponded to the integer index of the target word.  Since nn.NLLLoss was 
